@@ -25,12 +25,21 @@ optParser = optparse.OptionParser()
 optParser.add_option("--world", dest="world", default="", help="Path to the world to load.")
 optParser.add_option("--mode", dest="mode", default="realtime", help="Startup mode.")
 optParser.add_option("--no-gui", dest="noGui", default="false", help="Start Webots with minimal GUI.")
+optParser.add_option("--stream", dest="stream", default="false", help="Start Webots streaming server.")
 options, args = optParser.parse_args()
 
 if 'WEBOTS_HOME' not in os.environ:
     sys.exit('WEBOTS_HOME environment variable not defined.')
+
 command = [os.path.join(os.environ['WEBOTS_HOME'], 'webots'), '--mode=' + options.mode, options.world]
-if options.noGui == 'true':
+
+if options.stream.lower() != 'false':
+    if options.stream.lower() == 'true':
+        command.append('--stream="port=1234;mode=x3d;monitorActivity"')
+    else:
+        command.append('--stream="' + options.stream + '"')
+
+if options.noGui.lower() == 'true':
     command.append('--stdout')
     command.append('--stderr')
     command.append('--batch')
